# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csensor.proto\x12\rSensorPackage\"\x15\n\x13SensorCommonRequest\"1\n\x14SensorCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\")\n\x15\x44istanceSensorRequest\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\"5\n\x12\x44istanceSensorInfo\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"d\n\x16\x44istanceSensorResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12/\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32!.SensorPackage.DistanceSensorInfo\"\xd5\x01\n\rIMUSensorInfo\x12\x0e\n\x06gyro_x\x18\x01 \x01(\x02\x12\x0e\n\x06gyro_y\x18\x02 \x01(\x02\x12\x0e\n\x06gyro_z\x18\x03 \x01(\x02\x12\x0f\n\x07\x61\x63\x63\x65l_x\x18\x04 \x01(\x02\x12\x0f\n\x07\x61\x63\x63\x65l_y\x18\x05 \x01(\x02\x12\x0f\n\x07\x61\x63\x63\x65l_z\x18\x06 \x01(\x02\x12\x11\n\tcompass_x\x18\x07 \x01(\x02\x12\x11\n\tcompass_y\x18\x08 \x01(\x02\x12\x11\n\tcompass_z\x18\t \x01(\x02\x12\x0c\n\x04roll\x18\n \x01(\x02\x12\r\n\x05pitch\x18\x0b \x01(\x02\x12\x0b\n\x03yaw\x18\x0c \x01(\x02\"Z\n\x11IMUSensorResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1c.SensorPackage.IMUSensorInfo\"\x17\n\x15StartCalibrateRequest\"P\n\x16StartCalibrateResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04step\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\"\x18\n\x16\x43\x61ncelCalibrateRequest\"4\n\x17\x43\x61ncelCalibrateResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x15\n\x13\x41ttitudeTiltRequest\"\xb6\x01\n\x14\x41ttitudeTiltResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x14\n\x0ctilt_forward\x18\x03 \x01(\x08\x12\x11\n\ttilt_back\x18\x04 \x01(\x08\x12\x11\n\ttilt_left\x18\x05 \x01(\x08\x12\x12\n\ntilt_right\x18\x06 \x01(\x08\x12\x0f\n\x07\x66\x61\x63\x65_up\x18\x07 \x01(\x08\x12\x11\n\tface_down\x18\x08 \x01(\x08\x12\x0f\n\x07shaking\x18\t \x01(\x08\x32\xc4\x06\n\x11SensorServiceGrpc\x12g\n\x16getDistanceSensorValue\x12$.SensorPackage.DistanceSensorRequest\x1a%.SensorPackage.DistanceSensorResponse\"\x00\x12l\n\x19startDistanceSensorStream\x12$.SensorPackage.DistanceSensorRequest\x1a%.SensorPackage.DistanceSensorResponse\"\x00\x30\x01\x12g\n\x18stopDistanceSensorStream\x12$.SensorPackage.DistanceSensorRequest\x1a#.SensorPackage.SensorCommonResponse\"\x00\x12[\n\x11getIMUSensorValue\x12\".SensorPackage.SensorCommonRequest\x1a .SensorPackage.IMUSensorResponse\"\x00\x12\x61\n\x0estartCalibrate\x12$.SensorPackage.StartCalibrateRequest\x1a%.SensorPackage.StartCalibrateResponse\"\x00\x30\x01\x12\x62\n\x0f\x63\x61ncelCalibrate\x12%.SensorPackage.CancelCalibrateRequest\x1a&.SensorPackage.CancelCalibrateResponse\"\x00\x12\\\n\x0fgetAttitudeTilt\x12\".SensorPackage.AttitudeTiltRequest\x1a#.SensorPackage.AttitudeTiltResponse\"\x00\x12m\n\x1a\x63\x61librateIMUWithAVFeedback\x12$.SensorPackage.StartCalibrateRequest\x1a%.SensorPackage.StartCalibrateResponse\"\x00\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sensor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SENSORCOMMONREQUEST._serialized_start=31
  _SENSORCOMMONREQUEST._serialized_end=52
  _SENSORCOMMONRESPONSE._serialized_start=54
  _SENSORCOMMONRESPONSE._serialized_end=103
  _DISTANCESENSORREQUEST._serialized_start=105
  _DISTANCESENSORREQUEST._serialized_end=146
  _DISTANCESENSORINFO._serialized_start=148
  _DISTANCESENSORINFO._serialized_end=201
  _DISTANCESENSORRESPONSE._serialized_start=203
  _DISTANCESENSORRESPONSE._serialized_end=303
  _IMUSENSORINFO._serialized_start=306
  _IMUSENSORINFO._serialized_end=519
  _IMUSENSORRESPONSE._serialized_start=521
  _IMUSENSORRESPONSE._serialized_end=611
  _STARTCALIBRATEREQUEST._serialized_start=613
  _STARTCALIBRATEREQUEST._serialized_end=636
  _STARTCALIBRATERESPONSE._serialized_start=638
  _STARTCALIBRATERESPONSE._serialized_end=718
  _CANCELCALIBRATEREQUEST._serialized_start=720
  _CANCELCALIBRATEREQUEST._serialized_end=744
  _CANCELCALIBRATERESPONSE._serialized_start=746
  _CANCELCALIBRATERESPONSE._serialized_end=798
  _ATTITUDETILTREQUEST._serialized_start=800
  _ATTITUDETILTREQUEST._serialized_end=821
  _ATTITUDETILTRESPONSE._serialized_start=824
  _ATTITUDETILTRESPONSE._serialized_end=1006
  _SENSORSERVICEGRPC._serialized_start=1009
  _SENSORSERVICEGRPC._serialized_end=1845
# @@protoc_insertion_point(module_scope)
