# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmodel.proto\x12\x0cModelPackage\"\x88\x01\n\x12ModelControlParams\x12\x14\n\x0clinear_speed\x18\x01 \x01(\x05\x12\x11\n\tdirection\x18\x02 \x01(\x05\x12\x14\n\x0crotate_speed\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x05\x12\x0f\n\x07mileage\x18\x05 \x01(\x05\x12\x14\n\x0ctarget_angle\x18\x06 \x01(\x05\"j\n\x13ModelControlRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32 .ModelPackage.ModelControlParams\x12\x13\n\x0b\x63lient_type\x18\x03 \x01(\x05\">\n\x13ModelCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"\\\n\x12MotorControlParams\x12\x10\n\x08lf_joint\x18\x01 \x01(\x05\x12\x10\n\x08rf_joint\x18\x02 \x01(\x05\x12\x10\n\x08lb_joint\x18\x03 \x01(\x05\x12\x10\n\x08rb_joint\x18\x04 \x01(\x05\"U\n\x13MotorControlRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32 .ModelPackage.MotorControlParams\"G\n\x10XYZControlParams\x12\x10\n\x08linear_x\x18\x01 \x01(\x05\x12\x10\n\x08linear_y\x18\x02 \x01(\x05\x12\x0f\n\x07\x61ngle_z\x18\x03 \x01(\x05\"Q\n\x11XYZControlRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12.\n\x06params\x18\x02 \x01(\x0b\x32\x1e.ModelPackage.XYZControlParams\"\"\n\x12MecanumStopRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"A\n\x1a\x42\x61lanceKeepBalancingParams\x12\r\n\x05start\x18\x01 \x01(\x08\x12\x14\n\x0ckeep_balance\x18\x02 \x01(\x08\"e\n\x1b\x42\x61lanceKeepBalancingRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.ModelPackage.BalanceKeepBalancingParams\"J\n\x19TransformArmsControlParam\x12\r\n\x05joint\x18\x01 \x01(\x05\x12\x10\n\x08position\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x03 \x01(\x05\"d\n\x1bTransformArmsControlRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32\'.ModelPackage.TransformArmsControlParam\")\n\x17TransformSetHeightParam\x12\x0e\n\x06height\x18\x01 \x01(\x05\"`\n\x19TransformSetHeightRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x35\n\x06params\x18\x02 \x01(\x0b\x32%.ModelPackage.TransformSetHeightParam\")\n\x17\x45nableAdaptivePoseParam\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x05\"`\n\x19\x45nableAdaptivePoseRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x35\n\x06params\x18\x02 \x01(\x0b\x32%.ModelPackage.EnableAdaptivePoseParam\"5\n TransformSetHeightIncrementParam\x12\x11\n\tincrement\x18\x01 \x01(\x05\"\x87\x01\n\"TransformSetHeightIncrementRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12>\n\x06params\x18\x02 \x01(\x0b\x32..ModelPackage.TransformSetHeightIncrementParam\x12\x13\n\x0b\x63lient_type\x18\x03 \x01(\x05\")\n\x19WheelleggedRestoryRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"7\n\x19WheelleggedSetHeightParam\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04gear\x18\x02 \x01(\x05\"d\n\x1bWheelleggedSetHeightRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32\'.ModelPackage.WheelleggedSetHeightParam\"G\n\x1cWheelleggedSetLeanAngleParam\x12\x0c\n\x04pose\x18\x01 \x01(\x05\x12\x19\n\x11inclination_angle\x18\x02 \x01(\x02\"j\n\x1eWheelleggedSetLeanAngleRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x01(\x0b\x32*.ModelPackage.WheelleggedSetLeanAngleParam\"\x86\x01\n\x15SetAccelerationParams\x12\x10\n\x08linear_x\x18\x01 \x01(\x01\x12\x10\n\x08linear_y\x18\x02 \x01(\x01\x12\x10\n\x08linear_z\x18\x03 \x01(\x01\x12\x11\n\tangular_x\x18\x04 \x01(\x01\x12\x11\n\tangular_y\x18\x05 \x01(\x01\x12\x11\n\tangular_z\x18\x06 \x01(\x01\"[\n\x16SetAccelerationRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x33\n\x06params\x18\x02 \x01(\x0b\x32#.ModelPackage.SetAccelerationParams\"(\n\x18ResetAccelerationRequest\x12\x0c\n\x04type\x18\x01 \x01(\t2\x8a\x0b\n\x10ModelServiceGrpc\x12\\\n\x12modelCommonControl\x12!.ModelPackage.ModelControlRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12]\n\x13mecanumMotorControl\x12!.ModelPackage.MotorControlRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12Y\n\x11mecanumXYZControl\x12\x1f.ModelPackage.XYZControlRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12T\n\x0bmecanumStop\x12 .ModelPackage.MecanumStopRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x66\n\x14\x62\x61lanceKeepBalancing\x12).ModelPackage.BalanceKeepBalancingRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x66\n\x14transformArmsControl\x12).ModelPackage.TransformArmsControlRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x62\n\x12transformSetHeight\x12\'.ModelPackage.TransformSetHeightRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x62\n\x12\x65nableAdaptivePose\x12\'.ModelPackage.EnableAdaptivePoseRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12v\n\x1dtransformSetHeightByIncrement\x12\x30.ModelPackage.TransformSetHeightIncrementRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x62\n\x12wheelleggedRestory\x12\'.ModelPackage.WheelleggedRestoryRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\x66\n\x14wheelleggedSetHeight\x12).ModelPackage.WheelleggedSetHeightRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12l\n\x17wheelleggedSetLeanAngle\x12,.ModelPackage.WheelleggedSetLeanAngleRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12\\\n\x0fsetAcceleration\x12$.ModelPackage.SetAccelerationRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x12`\n\x11resetAcceleration\x12&.ModelPackage.ResetAccelerationRequest\x1a!.ModelPackage.ModelCommonResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MODELCONTROLPARAMS._serialized_start=30
  _MODELCONTROLPARAMS._serialized_end=166
  _MODELCONTROLREQUEST._serialized_start=168
  _MODELCONTROLREQUEST._serialized_end=274
  _MODELCOMMONRESPONSE._serialized_start=276
  _MODELCOMMONRESPONSE._serialized_end=338
  _MOTORCONTROLPARAMS._serialized_start=340
  _MOTORCONTROLPARAMS._serialized_end=432
  _MOTORCONTROLREQUEST._serialized_start=434
  _MOTORCONTROLREQUEST._serialized_end=519
  _XYZCONTROLPARAMS._serialized_start=521
  _XYZCONTROLPARAMS._serialized_end=592
  _XYZCONTROLREQUEST._serialized_start=594
  _XYZCONTROLREQUEST._serialized_end=675
  _MECANUMSTOPREQUEST._serialized_start=677
  _MECANUMSTOPREQUEST._serialized_end=711
  _BALANCEKEEPBALANCINGPARAMS._serialized_start=713
  _BALANCEKEEPBALANCINGPARAMS._serialized_end=778
  _BALANCEKEEPBALANCINGREQUEST._serialized_start=780
  _BALANCEKEEPBALANCINGREQUEST._serialized_end=881
  _TRANSFORMARMSCONTROLPARAM._serialized_start=883
  _TRANSFORMARMSCONTROLPARAM._serialized_end=957
  _TRANSFORMARMSCONTROLREQUEST._serialized_start=959
  _TRANSFORMARMSCONTROLREQUEST._serialized_end=1059
  _TRANSFORMSETHEIGHTPARAM._serialized_start=1061
  _TRANSFORMSETHEIGHTPARAM._serialized_end=1102
  _TRANSFORMSETHEIGHTREQUEST._serialized_start=1104
  _TRANSFORMSETHEIGHTREQUEST._serialized_end=1200
  _ENABLEADAPTIVEPOSEPARAM._serialized_start=1202
  _ENABLEADAPTIVEPOSEPARAM._serialized_end=1243
  _ENABLEADAPTIVEPOSEREQUEST._serialized_start=1245
  _ENABLEADAPTIVEPOSEREQUEST._serialized_end=1341
  _TRANSFORMSETHEIGHTINCREMENTPARAM._serialized_start=1343
  _TRANSFORMSETHEIGHTINCREMENTPARAM._serialized_end=1396
  _TRANSFORMSETHEIGHTINCREMENTREQUEST._serialized_start=1399
  _TRANSFORMSETHEIGHTINCREMENTREQUEST._serialized_end=1534
  _WHEELLEGGEDRESTORYREQUEST._serialized_start=1536
  _WHEELLEGGEDRESTORYREQUEST._serialized_end=1577
  _WHEELLEGGEDSETHEIGHTPARAM._serialized_start=1579
  _WHEELLEGGEDSETHEIGHTPARAM._serialized_end=1634
  _WHEELLEGGEDSETHEIGHTREQUEST._serialized_start=1636
  _WHEELLEGGEDSETHEIGHTREQUEST._serialized_end=1736
  _WHEELLEGGEDSETLEANANGLEPARAM._serialized_start=1738
  _WHEELLEGGEDSETLEANANGLEPARAM._serialized_end=1809
  _WHEELLEGGEDSETLEANANGLEREQUEST._serialized_start=1811
  _WHEELLEGGEDSETLEANANGLEREQUEST._serialized_end=1917
  _SETACCELERATIONPARAMS._serialized_start=1920
  _SETACCELERATIONPARAMS._serialized_end=2054
  _SETACCELERATIONREQUEST._serialized_start=2056
  _SETACCELERATIONREQUEST._serialized_end=2147
  _RESETACCELERATIONREQUEST._serialized_start=2149
  _RESETACCELERATIONREQUEST._serialized_end=2189
  _MODELSERVICEGRPC._serialized_start=2192
  _MODELSERVICEGRPC._serialized_end=3610
# @@protoc_insertion_point(module_scope)
