# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: audio.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61udio.proto\x12\x0c\x41udioPackage\"G\n\x0f\x41udioAsrRequest\x12\x11\n\tbegin_vad\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nd_vad\x18\x02 \x01(\x05\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\";\n\x10\x41udioAsrResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"3\n\x0f\x41udioTtsRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nvoice_type\x18\x02 \x01(\x05\"\x1f\n\x0f\x41udioNlpRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\";\n\x10\x41udioNlpResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\":\n\x10\x41udioFileRequest\x12\x12\n\naudio_name\x18\x01 \x01(\t\x12\x12\n\naudio_type\x18\x02 \x01(\x05\"*\n\x14\x41udioFileListRequest\x12\x12\n\naudio_type\x18\x01 \x01(\x05\"*\n\rAudioFileInfo\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0b\n\x03len\x18\x02 \x01(\x05\"^\n\x15\x41udioFileListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x05\x66iles\x18\x03 \x03(\x0b\x32\x1b.AudioPackage.AudioFileInfo\"P\n\x16ModifyAudioNameRequest\x12\x12\n\naudio_type\x18\x01 \x01(\x05\x12\x10\n\x08old_name\x18\x02 \x01(\t\x12\x10\n\x08new_name\x18\x03 \x01(\t\":\n\x10\x41udioPlayRequest\x12\x12\n\naudio_type\x18\x01 \x01(\x05\x12\x12\n\naudio_file\x18\x02 \x01(\t\"=\n\x13\x41udioRecordResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0b\n\x03len\x18\x03 \x01(\x05\")\n\x15\x41udioDirectionRequest\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\"B\n\x16\x41udioDirectionResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\r\n\x05\x61ngle\x18\x03 \x01(\x05\"\x13\n\x11\x41udioEmptyRequest\"0\n\x13\x41udioCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"I\n\x10\x41udioRmsResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\r\n\x05\x61ngle\x18\x03 \x01(\x05\x12\x0b\n\x03rms\x18\x04 \x01(\x05\x32\xd3\n\n\x10\x41udioServiceGrpc\x12N\n\x0bsetAudioAsr\x12\x1d.AudioPackage.AudioAsrRequest\x1a\x1e.AudioPackage.AudioAsrResponse\"\x00\x12Q\n\x0bsetAudioTts\x12\x1d.AudioPackage.AudioTtsRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12N\n\x0bsetAudioNlp\x12\x1d.AudioPackage.AudioNlpRequest\x1a\x1e.AudioPackage.AudioNlpResponse\"\x00\x12V\n\x0finsertAudioFile\x12\x1e.AudioPackage.AudioFileRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12V\n\x0f\x64\x65leteAudioFile\x12\x1e.AudioPackage.AudioFileRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12]\n\x10getAudioFileList\x12\".AudioPackage.AudioFileListRequest\x1a#.AudioPackage.AudioFileListResponse\"\x00\x12`\n\x13modifyAudioFileName\x12$.AudioPackage.ModifyAudioNameRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12T\n\rplayAudioFile\x12\x1e.AudioPackage.AudioPlayRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12\\\n\x14startRecordAudioFile\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12[\n\x13stopRecordAudioFile\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioRecordResponse\"\x00\x12U\n\rstopPlayAudio\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12\x62\n\x13getDirectionOfAudio\x12#.AudioPackage.AudioDirectionRequest\x1a$.AudioPackage.AudioDirectionResponse\"\x00\x12\\\n\x14\x65nableAudioDirection\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12]\n\x15\x64isableAudioDirection\x12\x1f.AudioPackage.AudioEmptyRequest\x1a!.AudioPackage.AudioCommonResponse\"\x00\x12R\n\rgetCurrentRms\x12\x1f.AudioPackage.AudioEmptyRequest\x1a\x1e.AudioPackage.AudioRmsResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'audio_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUDIOASRREQUEST._serialized_start=29
  _AUDIOASRREQUEST._serialized_end=100
  _AUDIOASRRESPONSE._serialized_start=102
  _AUDIOASRRESPONSE._serialized_end=161
  _AUDIOTTSREQUEST._serialized_start=163
  _AUDIOTTSREQUEST._serialized_end=214
  _AUDIONLPREQUEST._serialized_start=216
  _AUDIONLPREQUEST._serialized_end=247
  _AUDIONLPRESPONSE._serialized_start=249
  _AUDIONLPRESPONSE._serialized_end=308
  _AUDIOFILEREQUEST._serialized_start=310
  _AUDIOFILEREQUEST._serialized_end=368
  _AUDIOFILELISTREQUEST._serialized_start=370
  _AUDIOFILELISTREQUEST._serialized_end=412
  _AUDIOFILEINFO._serialized_start=414
  _AUDIOFILEINFO._serialized_end=456
  _AUDIOFILELISTRESPONSE._serialized_start=458
  _AUDIOFILELISTRESPONSE._serialized_end=552
  _MODIFYAUDIONAMEREQUEST._serialized_start=554
  _MODIFYAUDIONAMEREQUEST._serialized_end=634
  _AUDIOPLAYREQUEST._serialized_start=636
  _AUDIOPLAYREQUEST._serialized_end=694
  _AUDIORECORDRESPONSE._serialized_start=696
  _AUDIORECORDRESPONSE._serialized_end=757
  _AUDIODIRECTIONREQUEST._serialized_start=759
  _AUDIODIRECTIONREQUEST._serialized_end=800
  _AUDIODIRECTIONRESPONSE._serialized_start=802
  _AUDIODIRECTIONRESPONSE._serialized_end=868
  _AUDIOEMPTYREQUEST._serialized_start=870
  _AUDIOEMPTYREQUEST._serialized_end=889
  _AUDIOCOMMONRESPONSE._serialized_start=891
  _AUDIOCOMMONRESPONSE._serialized_end=939
  _AUDIORMSRESPONSE._serialized_start=941
  _AUDIORMSRESPONSE._serialized_end=1014
  _AUDIOSERVICEGRPC._serialized_start=1017
  _AUDIOSERVICEGRPC._serialized_end=2380
# @@protoc_insertion_point(module_scope)
