# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gpio.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ngpio.proto\x12\x0bGpioPackage\"2\n\x14SetGpioExportRequest\x12\x0b\n\x03pin\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"2\n\x15SetGpioExportResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x1e\n\x0fReadGpioRequest\x12\x0b\n\x03pin\x18\x01 \x01(\t\"=\n\x10ReadGpioResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0e\n\x06result\x18\x03 \x01(\t\"a\n\x1cSetGpioStartExportPwmRequest\x12\x0b\n\x03pin\x18\x01 \x01(\t\x12\x11\n\tfrequency\x18\x02 \x01(\x04\x12\x12\n\nduty_cycle\x18\x03 \x01(\x04\x12\r\n\x05range\x18\x04 \x01(\x04\":\n\x1dSetGpioStartExportPwmResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"*\n\x1bSetGpioStopExportPwmRequest\x12\x0b\n\x03pin\x18\x01 \x01(\t\"9\n\x1cSetGpioStopExportPwmResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"3\n\x11SetSerbaudRequest\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61udrate\x18\x02 \x01(\x04\"/\n\x12SetSerbaudResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"8\n\x19SerialExportStringRequest\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"7\n\x1aSerialExportStringResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"%\n\x15SerialReadByteRequest\x12\x0c\n\x04port\x18\x01 \x01(\t\"C\n\x16SerialReadByteResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0e\n\x06result\x18\x03 \x01(\t\"\'\n\x17SerialReadStringRequest\x12\x0c\n\x04port\x18\x01 \x01(\t\"E\n\x18SerialReadStringResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0e\n\x06result\x18\x03 \x01(\t\"4\n\x15SerialReadUtilRequest\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\r\n\x05\x63har_\x18\x02 \x01(\t\"C\n\x16SerialReadUtilResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0e\n\x06result\x18\x03 \x01(\t\"\x1e\n\x1c\x43learAllGpioAndSerialRequest\":\n\x1d\x43learAllGpioAndSerialResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xe0\x07\n\x0fGpioServiceGrpc\x12X\n\rsetGpioExport\x12!.GpioPackage.SetGpioExportRequest\x1a\".GpioPackage.SetGpioExportResponse\"\x00\x12I\n\x08readGpio\x12\x1c.GpioPackage.ReadGpioRequest\x1a\x1d.GpioPackage.ReadGpioResponse\"\x00\x12p\n\x15setGpioStartExportPwm\x12).GpioPackage.SetGpioStartExportPwmRequest\x1a*.GpioPackage.SetGpioStartExportPwmResponse\"\x00\x12m\n\x14setGpioStopExportPwm\x12(.GpioPackage.SetGpioStopExportPwmRequest\x1a).GpioPackage.SetGpioStopExportPwmResponse\"\x00\x12O\n\nsetSerbaud\x12\x1e.GpioPackage.SetSerbaudRequest\x1a\x1f.GpioPackage.SetSerbaudResponse\"\x00\x12g\n\x12serialExportString\x12&.GpioPackage.SerialExportStringRequest\x1a\'.GpioPackage.SerialExportStringResponse\"\x00\x12[\n\x0eserialReadByte\x12\".GpioPackage.SerialReadByteRequest\x1a#.GpioPackage.SerialReadByteResponse\"\x00\x12\x61\n\x10serialReadString\x12$.GpioPackage.SerialReadStringRequest\x1a%.GpioPackage.SerialReadStringResponse\"\x00\x12[\n\x0eserialReadUtil\x12\".GpioPackage.SerialReadUtilRequest\x1a#.GpioPackage.SerialReadUtilResponse\"\x00\x12p\n\x15\x63learAllGpioAndSerial\x12).GpioPackage.ClearAllGpioAndSerialRequest\x1a*.GpioPackage.ClearAllGpioAndSerialResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gpio_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SETGPIOEXPORTREQUEST._serialized_start=27
  _SETGPIOEXPORTREQUEST._serialized_end=77
  _SETGPIOEXPORTRESPONSE._serialized_start=79
  _SETGPIOEXPORTRESPONSE._serialized_end=129
  _READGPIOREQUEST._serialized_start=131
  _READGPIOREQUEST._serialized_end=161
  _READGPIORESPONSE._serialized_start=163
  _READGPIORESPONSE._serialized_end=224
  _SETGPIOSTARTEXPORTPWMREQUEST._serialized_start=226
  _SETGPIOSTARTEXPORTPWMREQUEST._serialized_end=323
  _SETGPIOSTARTEXPORTPWMRESPONSE._serialized_start=325
  _SETGPIOSTARTEXPORTPWMRESPONSE._serialized_end=383
  _SETGPIOSTOPEXPORTPWMREQUEST._serialized_start=385
  _SETGPIOSTOPEXPORTPWMREQUEST._serialized_end=427
  _SETGPIOSTOPEXPORTPWMRESPONSE._serialized_start=429
  _SETGPIOSTOPEXPORTPWMRESPONSE._serialized_end=486
  _SETSERBAUDREQUEST._serialized_start=488
  _SETSERBAUDREQUEST._serialized_end=539
  _SETSERBAUDRESPONSE._serialized_start=541
  _SETSERBAUDRESPONSE._serialized_end=588
  _SERIALEXPORTSTRINGREQUEST._serialized_start=590
  _SERIALEXPORTSTRINGREQUEST._serialized_end=646
  _SERIALEXPORTSTRINGRESPONSE._serialized_start=648
  _SERIALEXPORTSTRINGRESPONSE._serialized_end=703
  _SERIALREADBYTEREQUEST._serialized_start=705
  _SERIALREADBYTEREQUEST._serialized_end=742
  _SERIALREADBYTERESPONSE._serialized_start=744
  _SERIALREADBYTERESPONSE._serialized_end=811
  _SERIALREADSTRINGREQUEST._serialized_start=813
  _SERIALREADSTRINGREQUEST._serialized_end=852
  _SERIALREADSTRINGRESPONSE._serialized_start=854
  _SERIALREADSTRINGRESPONSE._serialized_end=923
  _SERIALREADUTILREQUEST._serialized_start=925
  _SERIALREADUTILREQUEST._serialized_end=977
  _SERIALREADUTILRESPONSE._serialized_start=979
  _SERIALREADUTILRESPONSE._serialized_end=1046
  _CLEARALLGPIOANDSERIALREQUEST._serialized_start=1048
  _CLEARALLGPIOANDSERIALREQUEST._serialized_end=1078
  _CLEARALLGPIOANDSERIALRESPONSE._serialized_start=1080
  _CLEARALLGPIOANDSERIALRESPONSE._serialized_end=1138
  _GPIOSERVICEGRPC._serialized_start=1141
  _GPIOSERVICEGRPC._serialized_end=2133
# @@protoc_insertion_point(module_scope)
