# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vision.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cvision.proto\x12\x0f\x41IVisionPackage\"7\n\x10TrainAndSavePara\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rcategoryNames\x18\x02 \x03(\t\"U\n\x13TrainAndSaveRequest\x12\r\n\x05model\x18\x01 \x01(\t\x12/\n\x04para\x18\x02 \x01(\x0b\x32!.AIVisionPackage.TrainAndSavePara\"?\n\x14TrainAndSaveResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\".\n\x0fLoadModelInfoIn\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0c\n\x04para\x18\x02 \x01(\t\"D\n\x10LoadModelRequest\x12\x30\n\x06models\x18\x01 \x03(\x0b\x32 .AIVisionPackage.LoadModelInfoIn\"<\n\x11LoadModelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"B\n\x13SetModelParaRequest\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0e\n\x06invoke\x18\x02 \x01(\t\x12\x0c\n\x04para\x18\x03 \x01(\t\"?\n\x14SetModelParaResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"/\n\x10InferenceModelIn\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0c\n\x04para\x18\x02 \x01(\t\"W\n\x10InferenceRequest\x12\x10\n\x08need_pic\x18\x01 \x01(\x08\x12\x31\n\x06models\x18\x02 \x03(\x0b\x32!.AIVisionPackage.InferenceModelIn\"0\n\x11InferenceModelOut\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"S\n\rInferenceData\x12\x0b\n\x03img\x18\x01 \x01(\t\x12\x35\n\tinference\x18\x02 \x03(\x0b\x32\".AIVisionPackage.InferenceModelOut\"\\\n\x11InferenceResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12,\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1e.AIVisionPackage.InferenceData\"%\n\x13ReleaseModelRequest\x12\x0e\n\x06models\x18\x01 \x03(\t\"?\n\x14ReleaseModelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"&\n\x14\x41utoInferenceRequest\x12\x0e\n\x06models\x18\x01 \x03(\t\"B\n\x14\x43\x61meraNumberResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x65v_num\x18\x03 \x01(\x05\"\x0e\n\x0c\x45mptyRequest\"+\n\x0e\x43ommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xbe\x07\n\x13\x41IVisionServiceGrpc\x12_\n\x0ctrainAndSave\x12$.AIVisionPackage.TrainAndSaveRequest\x1a%.AIVisionPackage.TrainAndSaveResponse\"\x00\x30\x01\x12T\n\tloadModel\x12!.AIVisionPackage.LoadModelRequest\x1a\".AIVisionPackage.LoadModelResponse\"\x00\x12]\n\x0csetModelPara\x12$.AIVisionPackage.SetModelParaRequest\x1a%.AIVisionPackage.SetModelParaResponse\"\x00\x12[\n\x10\x64oModelInference\x12!.AIVisionPackage.InferenceRequest\x1a\".AIVisionPackage.InferenceResponse\"\x00\x12]\n\x0creleaseModel\x12$.AIVisionPackage.ReleaseModelRequest\x1a%.AIVisionPackage.ReleaseModelResponse\"\x00\x12\x63\n\x12startAutoInference\x12%.AIVisionPackage.AutoInferenceRequest\x1a\".AIVisionPackage.InferenceResponse\"\x00\x30\x01\x12U\n\x11stopAutoInference\x12\x1d.AIVisionPackage.EmptyRequest\x1a\x1f.AIVisionPackage.CommonResponse\"\x00\x12\x61\n\x18startPushInferenceResult\x12\x1d.AIVisionPackage.EmptyRequest\x1a\".AIVisionPackage.InferenceResponse\"\x00\x30\x01\x12[\n\x17stopPushInferenceResult\x12\x1d.AIVisionPackage.EmptyRequest\x1a\x1f.AIVisionPackage.CommonResponse\"\x00\x12Y\n\x0fgetCameraNumber\x12\x1d.AIVisionPackage.EmptyRequest\x1a%.AIVisionPackage.CameraNumberResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vision_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRAINANDSAVEPARA._serialized_start=33
  _TRAINANDSAVEPARA._serialized_end=88
  _TRAINANDSAVEREQUEST._serialized_start=90
  _TRAINANDSAVEREQUEST._serialized_end=175
  _TRAINANDSAVERESPONSE._serialized_start=177
  _TRAINANDSAVERESPONSE._serialized_end=240
  _LOADMODELINFOIN._serialized_start=242
  _LOADMODELINFOIN._serialized_end=288
  _LOADMODELREQUEST._serialized_start=290
  _LOADMODELREQUEST._serialized_end=358
  _LOADMODELRESPONSE._serialized_start=360
  _LOADMODELRESPONSE._serialized_end=420
  _SETMODELPARAREQUEST._serialized_start=422
  _SETMODELPARAREQUEST._serialized_end=488
  _SETMODELPARARESPONSE._serialized_start=490
  _SETMODELPARARESPONSE._serialized_end=553
  _INFERENCEMODELIN._serialized_start=555
  _INFERENCEMODELIN._serialized_end=602
  _INFERENCEREQUEST._serialized_start=604
  _INFERENCEREQUEST._serialized_end=691
  _INFERENCEMODELOUT._serialized_start=693
  _INFERENCEMODELOUT._serialized_end=741
  _INFERENCEDATA._serialized_start=743
  _INFERENCEDATA._serialized_end=826
  _INFERENCERESPONSE._serialized_start=828
  _INFERENCERESPONSE._serialized_end=920
  _RELEASEMODELREQUEST._serialized_start=922
  _RELEASEMODELREQUEST._serialized_end=959
  _RELEASEMODELRESPONSE._serialized_start=961
  _RELEASEMODELRESPONSE._serialized_end=1024
  _AUTOINFERENCEREQUEST._serialized_start=1026
  _AUTOINFERENCEREQUEST._serialized_end=1064
  _CAMERANUMBERRESPONSE._serialized_start=1066
  _CAMERANUMBERRESPONSE._serialized_end=1132
  _EMPTYREQUEST._serialized_start=1134
  _EMPTYREQUEST._serialized_end=1148
  _COMMONRESPONSE._serialized_start=1150
  _COMMONRESPONSE._serialized_end=1193
  _AIVISIONSERVICEGRPC._serialized_start=1196
  _AIVISIONSERVICEGRPC._serialized_end=2154
# @@protoc_insertion_point(module_scope)
