# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: device.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x64\x65vice.proto\x12\rDevicePackage\"B\n\x12LightEffectRequest\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x01 \x01(\x05\x12\r\n\x05level\x18\x02 \x01(\x05\x12\r\n\x05\x63olor\x18\x03 \x01(\r\"c\n\x11LightColorRequest\x12\x11\n\ttop_light\x18\x01 \x01(\x05\x12\x12\n\nleft_light\x18\x02 \x01(\x05\x12\x13\n\x0bright_light\x18\x03 \x01(\x05\x12\x12\n\ndown_light\x18\x04 \x01(\x05\"%\n\x13TurnOffLightRequest\x12\x0e\n\x06lights\x18\x01 \x03(\x05\"*\n\rLightResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x13\n\x11\x44\x65viceListRequest\"N\n\nDeviceInfo\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08\x66irmware\x18\x03 \x01(\t\x12\x0e\n\x06serial\x18\x04 \x01(\t\"@\n\x0e\x44\x65viceListInfo\x12.\n\x0b\x64\x65vice_list\x18\x01 \x03(\x0b\x32\x19.DevicePackage.DeviceInfo\"\xb6\x01\n\x12\x44\x65viceListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32+.DevicePackage.DeviceListResponse.DataEntry\x1aJ\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.DevicePackage.DeviceListInfo:\x02\x38\x01\"\x13\n\x11\x44\x65viceNameRequest\"=\n\x12\x44\x65viceNameResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"W\n\x0f\x44isplayTextInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x11\n\tfont_size\x18\x02 \x01(\x05\x12\x12\n\nfont_color\x18\x03 \x01(\t\x12\x0f\n\x07newline\x18\x04 \x01(\x08\"\x80\x01\n\x10\x44isplayUIRequest\x12\x18\n\x10\x62\x61\x63kground_color\x18\x01 \x01(\t\x12\x10\n\x08img_name\x18\x02 \x01(\t\x12\x31\n\ttext_list\x18\x03 \x03(\x0b\x32\x1e.DevicePackage.DisplayTextInfo\x12\r\n\x05reset\x18\x04 \x01(\x08\"\x1b\n\x19\x44isplayPictureListRequest\".\n\x11\x44isplayUIResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"J\n\x1a\x44isplayPictureListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x11\n\tname_list\x18\x03 \x03(\t\"/\n\x1b\x44\x65leteDisplayPictureRequest\x12\x10\n\x08img_name\x18\x01 \x01(\t\"\'\n\x14SetBrightnessRequest\x12\x0f\n\x07percent\x18\x01 \x01(\x05\"\x16\n\x14GetBrightnessRequest\"@\n\x12\x42rightnessResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0f\n\x07percent\x18\x03 \x01(\x05\"\x13\n\x11MacAddressRequest\"<\n\x12MacAddressResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0b\n\x03mac\x18\x03 \x01(\t\"2\n\x10SetVolumeRequest\x12\x0e\n\x06volume\x18\x01 \x01(\x05\x12\x0e\n\x06stream\x18\x02 \x01(\x05\"\x12\n\x10GetVolumeRequest\"K\n\x0eVolumeResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0e\n\x06volume\x18\x03 \x01(\x05\x12\x0e\n\x06isMute\x18\x04 \x01(\x08\"!\n\x11MuteVolumeRequest\x12\x0c\n\x04mute\x18\x01 \x01(\x08\"2\n\x12SelectModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\"0\n\x13SelectModelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x14\n\x12\x44\x65viceModelRequest\">\n\x13\x44\x65viceModelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"L\n\x15\x44\x65viceVersionResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x18\n\x10software_version\x18\x03 \x01(\t\"\x15\n\x13\x44\x65viceCommonRequest\"1\n\x14\x44\x65viceCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xe0\r\n\x11\x44\x65viceServiceGrpc\x12V\n\rgetDeviceList\x12 .DevicePackage.DeviceListRequest\x1a!.DevicePackage.DeviceListResponse\"\x00\x12h\n\x1dstartDeviceListChangeListener\x12 .DevicePackage.DeviceListRequest\x1a!.DevicePackage.DeviceListResponse\"\x00\x30\x01\x12g\n\x1cstopDeviceListChangeListener\x12 .DevicePackage.DeviceListRequest\x1a#.DevicePackage.DeviceCommonResponse\"\x00\x12S\n\x0csetDisplayUI\x12\x1f.DevicePackage.DisplayUIRequest\x1a .DevicePackage.DisplayUIResponse\"\x00\x12n\n\x15getDisplayPictureList\x12(.DevicePackage.DisplayPictureListRequest\x1a).DevicePackage.DisplayPictureListResponse\"\x00\x12i\n\x14\x64\x65leteDisplayPicture\x12*.DevicePackage.DeleteDisplayPictureRequest\x1a#.DevicePackage.DeviceCommonResponse\"\x00\x12Z\n\rstopDisplayUI\x12\".DevicePackage.DeviceCommonRequest\x1a#.DevicePackage.DeviceCommonResponse\"\x00\x12Y\n\rsetBrightness\x12#.DevicePackage.SetBrightnessRequest\x1a!.DevicePackage.BrightnessResponse\"\x00\x12Y\n\rgetBrightness\x12#.DevicePackage.GetBrightnessRequest\x1a!.DevicePackage.BrightnessResponse\"\x00\x12V\n\rgetMacAddress\x12 .DevicePackage.MacAddressRequest\x1a!.DevicePackage.MacAddressResponse\"\x00\x12M\n\tsetVolume\x12\x1f.DevicePackage.SetVolumeRequest\x1a\x1d.DevicePackage.VolumeResponse\"\x00\x12M\n\tgetVolume\x12\x1f.DevicePackage.GetVolumeRequest\x1a\x1d.DevicePackage.VolumeResponse\"\x00\x12O\n\nmuteVolume\x12 .DevicePackage.MuteVolumeRequest\x1a\x1d.DevicePackage.VolumeResponse\"\x00\x12V\n\x0bselectModel\x12!.DevicePackage.SelectModelRequest\x1a\".DevicePackage.SelectModelResponse\"\x00\x12Y\n\x0egetDeviceModel\x12!.DevicePackage.DeviceModelRequest\x1a\".DevicePackage.DeviceModelResponse\"\x00\x12\x66\n\x18getDeviceSoftwareVersion\x12\".DevicePackage.DeviceCommonRequest\x1a$.DevicePackage.DeviceVersionResponse\"\x00\x12T\n\x0fshowLightEffect\x12!.DevicePackage.LightEffectRequest\x1a\x1c.DevicePackage.LightResponse\"\x00\x12R\n\x0eshowLightColor\x12 .DevicePackage.LightColorRequest\x1a\x1c.DevicePackage.LightResponse\"\x00\x12R\n\x0cturnOffLight\x12\".DevicePackage.TurnOffLightRequest\x1a\x1c.DevicePackage.LightResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEVICELISTRESPONSE_DATAENTRY._options = None
  _DEVICELISTRESPONSE_DATAENTRY._serialized_options = b'8\001'
  _LIGHTEFFECTREQUEST._serialized_start=31
  _LIGHTEFFECTREQUEST._serialized_end=97
  _LIGHTCOLORREQUEST._serialized_start=99
  _LIGHTCOLORREQUEST._serialized_end=198
  _TURNOFFLIGHTREQUEST._serialized_start=200
  _TURNOFFLIGHTREQUEST._serialized_end=237
  _LIGHTRESPONSE._serialized_start=239
  _LIGHTRESPONSE._serialized_end=281
  _DEVICELISTREQUEST._serialized_start=283
  _DEVICELISTREQUEST._serialized_end=302
  _DEVICEINFO._serialized_start=304
  _DEVICEINFO._serialized_end=382
  _DEVICELISTINFO._serialized_start=384
  _DEVICELISTINFO._serialized_end=448
  _DEVICELISTRESPONSE._serialized_start=451
  _DEVICELISTRESPONSE._serialized_end=633
  _DEVICELISTRESPONSE_DATAENTRY._serialized_start=559
  _DEVICELISTRESPONSE_DATAENTRY._serialized_end=633
  _DEVICENAMEREQUEST._serialized_start=635
  _DEVICENAMEREQUEST._serialized_end=654
  _DEVICENAMERESPONSE._serialized_start=656
  _DEVICENAMERESPONSE._serialized_end=717
  _DISPLAYTEXTINFO._serialized_start=719
  _DISPLAYTEXTINFO._serialized_end=806
  _DISPLAYUIREQUEST._serialized_start=809
  _DISPLAYUIREQUEST._serialized_end=937
  _DISPLAYPICTURELISTREQUEST._serialized_start=939
  _DISPLAYPICTURELISTREQUEST._serialized_end=966
  _DISPLAYUIRESPONSE._serialized_start=968
  _DISPLAYUIRESPONSE._serialized_end=1014
  _DISPLAYPICTURELISTRESPONSE._serialized_start=1016
  _DISPLAYPICTURELISTRESPONSE._serialized_end=1090
  _DELETEDISPLAYPICTUREREQUEST._serialized_start=1092
  _DELETEDISPLAYPICTUREREQUEST._serialized_end=1139
  _SETBRIGHTNESSREQUEST._serialized_start=1141
  _SETBRIGHTNESSREQUEST._serialized_end=1180
  _GETBRIGHTNESSREQUEST._serialized_start=1182
  _GETBRIGHTNESSREQUEST._serialized_end=1204
  _BRIGHTNESSRESPONSE._serialized_start=1206
  _BRIGHTNESSRESPONSE._serialized_end=1270
  _MACADDRESSREQUEST._serialized_start=1272
  _MACADDRESSREQUEST._serialized_end=1291
  _MACADDRESSRESPONSE._serialized_start=1293
  _MACADDRESSRESPONSE._serialized_end=1353
  _SETVOLUMEREQUEST._serialized_start=1355
  _SETVOLUMEREQUEST._serialized_end=1405
  _GETVOLUMEREQUEST._serialized_start=1407
  _GETVOLUMEREQUEST._serialized_end=1425
  _VOLUMERESPONSE._serialized_start=1427
  _VOLUMERESPONSE._serialized_end=1502
  _MUTEVOLUMEREQUEST._serialized_start=1504
  _MUTEVOLUMEREQUEST._serialized_end=1537
  _SELECTMODELREQUEST._serialized_start=1539
  _SELECTMODELREQUEST._serialized_end=1589
  _SELECTMODELRESPONSE._serialized_start=1591
  _SELECTMODELRESPONSE._serialized_end=1639
  _DEVICEMODELREQUEST._serialized_start=1641
  _DEVICEMODELREQUEST._serialized_end=1661
  _DEVICEMODELRESPONSE._serialized_start=1663
  _DEVICEMODELRESPONSE._serialized_end=1725
  _DEVICEVERSIONRESPONSE._serialized_start=1727
  _DEVICEVERSIONRESPONSE._serialized_end=1803
  _DEVICECOMMONREQUEST._serialized_start=1805
  _DEVICECOMMONREQUEST._serialized_end=1826
  _DEVICECOMMONRESPONSE._serialized_start=1828
  _DEVICECOMMONRESPONSE._serialized_end=1877
  _DEVICESERVICEGRPC._serialized_start=1880
  _DEVICESERVICEGRPC._serialized_end=3640
# @@protoc_insertion_point(module_scope)
