# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: power.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bpower.proto\x12\x0cPowerPackage\"\x0e\n\x0cPowerRequest\"x\n\x0ePowerValueInfo\x12\r\n\x05level\x18\x01 \x01(\x05\x12\r\n\x05scale\x18\x02 \x01(\x05\x12\x13\n\x0btemperature\x18\x03 \x01(\x02\x12\x0f\n\x07voltage\x18\x04 \x01(\x02\x12\x12\n\npower_plug\x18\x05 \x01(\x08\x12\x0e\n\x06status\x18\x06 \x01(\x05\"[\n\x12PowerValueResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1c.PowerPackage.PowerValueInfo\"0\n\x13PowerCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\x91\x02\n\x10PowerServiceGrpc\x12O\n\rgetPowerValue\x12\x1a.PowerPackage.PowerRequest\x1a .PowerPackage.PowerValueResponse\"\x00\x12V\n\x12startPowerListener\x12\x1a.PowerPackage.PowerRequest\x1a .PowerPackage.PowerValueResponse\"\x00\x30\x01\x12T\n\x11stopPowerListener\x12\x1a.PowerPackage.PowerRequest\x1a!.PowerPackage.PowerCommonResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'power_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POWERREQUEST._serialized_start=29
  _POWERREQUEST._serialized_end=43
  _POWERVALUEINFO._serialized_start=45
  _POWERVALUEINFO._serialized_end=165
  _POWERVALUERESPONSE._serialized_start=167
  _POWERVALUERESPONSE._serialized_end=258
  _POWERCOMMONRESPONSE._serialized_start=260
  _POWERCOMMONRESPONSE._serialized_end=308
  _POWERSERVICEGRPC._serialized_start=311
  _POWERSERVICEGRPC._serialized_end=584
# @@protoc_insertion_point(module_scope)
