# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bluetooth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62luetooth.proto\x12\x10\x42luetoothPackage\"\\\n\x08\x42tDevice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04rssi\x18\x04 \x01(\x05\x12\x14\n\x0cis_connected\x18\x05 \x01(\x08\"!\n\x0f\x42tEnableRequest\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x05\"-\n\x10\x42tEnableResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x11\n\x0f\x42tStatusRequest\"\x83\x01\n\x10\x42tStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0f\n\x07poweron\x18\x03 \x01(\x08\x12\x11\n\tconnected\x18\x04 \x01(\x08\x12\x30\n\x0cremoteDevice\x18\x05 \x01(\x0b\x32\x1a.BluetoothPackage.BtDevice\"\x1c\n\x1a\x42tFoundedDeviceListRequest\"\x9a\x01\n\x1b\x42tFoundedDeviceListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12/\n\x0bscaned_list\x18\x03 \x03(\x0b\x32\x1a.BluetoothPackage.BtDevice\x12/\n\x0bpaired_list\x18\x04 \x03(\x0b\x32\x1a.BluetoothPackage.BtDevice\"\x17\n\x15StartDiscoveryRequest\"_\n\x16StartDiscoveryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x1a.BluetoothPackage.BtDevice\"\x18\n\x16\x43\x61ncelDiscoveryRequest\"4\n\x17\x43\x61ncelDiscoveryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x14\n\x12IsDiscoveryRequest\"E\n\x13IsDiscoveryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x13\n\x0bis_dicovery\x18\x03 \x01(\x08\"\x15\n\x13\x42tDisconnectRequest\"1\n\x14\x42tDisconnectResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\" \n\rBtPairRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"+\n\x0e\x42tPairResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\"\n\x0f\x42tUnpairRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"-\n\x10\x42tUnpairResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x16\n\x14\x42tStateListenRequest\"2\n\x15\x42tStateListenResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xc1\x08\n\x14\x42luetoothServiceGrpc\x12T\n\tsetEnable\x12!.BluetoothPackage.BtEnableRequest\x1a\".BluetoothPackage.BtEnableResponse\"\x00\x12V\n\x0bgetBtStatus\x12!.BluetoothPackage.BtStatusRequest\x1a\".BluetoothPackage.BtStatusResponse\"\x00\x12\x64\n\x12startBtStateListen\x12&.BluetoothPackage.BtStateListenRequest\x1a\".BluetoothPackage.BtStatusResponse\"\x00\x30\x01\x12\x66\n\x11stopBtStateListen\x12&.BluetoothPackage.BtStateListenRequest\x1a\'.BluetoothPackage.BtStateListenResponse\"\x00\x12g\n\x0estartDiscovery\x12\'.BluetoothPackage.StartDiscoveryRequest\x1a(.BluetoothPackage.StartDiscoveryResponse\"\x00\x30\x01\x12h\n\x0f\x63\x61ncelDiscovery\x12(.BluetoothPackage.CancelDiscoveryRequest\x1a).BluetoothPackage.CancelDiscoveryResponse\"\x00\x12\\\n\x0bisDiscovery\x12$.BluetoothPackage.IsDiscoveryRequest\x1a%.BluetoothPackage.IsDiscoveryResponse\"\x00\x12w\n\x16getBtFoundedDeviceList\x12,.BluetoothPackage.BtFoundedDeviceListRequest\x1a-.BluetoothPackage.BtFoundedDeviceListResponse\"\x00\x12_\n\x0c\x64isconnectBt\x12%.BluetoothPackage.BtDisconnectRequest\x1a&.BluetoothPackage.BtDisconnectResponse\"\x00\x12M\n\x06pairBt\x12\x1f.BluetoothPackage.BtPairRequest\x1a .BluetoothPackage.BtPairResponse\"\x00\x12S\n\x08unpairBt\x12!.BluetoothPackage.BtUnpairRequest\x1a\".BluetoothPackage.BtUnpairResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bluetooth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BTDEVICE._serialized_start=37
  _BTDEVICE._serialized_end=129
  _BTENABLEREQUEST._serialized_start=131
  _BTENABLEREQUEST._serialized_end=164
  _BTENABLERESPONSE._serialized_start=166
  _BTENABLERESPONSE._serialized_end=211
  _BTSTATUSREQUEST._serialized_start=213
  _BTSTATUSREQUEST._serialized_end=230
  _BTSTATUSRESPONSE._serialized_start=233
  _BTSTATUSRESPONSE._serialized_end=364
  _BTFOUNDEDDEVICELISTREQUEST._serialized_start=366
  _BTFOUNDEDDEVICELISTREQUEST._serialized_end=394
  _BTFOUNDEDDEVICELISTRESPONSE._serialized_start=397
  _BTFOUNDEDDEVICELISTRESPONSE._serialized_end=551
  _STARTDISCOVERYREQUEST._serialized_start=553
  _STARTDISCOVERYREQUEST._serialized_end=576
  _STARTDISCOVERYRESPONSE._serialized_start=578
  _STARTDISCOVERYRESPONSE._serialized_end=673
  _CANCELDISCOVERYREQUEST._serialized_start=675
  _CANCELDISCOVERYREQUEST._serialized_end=699
  _CANCELDISCOVERYRESPONSE._serialized_start=701
  _CANCELDISCOVERYRESPONSE._serialized_end=753
  _ISDISCOVERYREQUEST._serialized_start=755
  _ISDISCOVERYREQUEST._serialized_end=775
  _ISDISCOVERYRESPONSE._serialized_start=777
  _ISDISCOVERYRESPONSE._serialized_end=846
  _BTDISCONNECTREQUEST._serialized_start=848
  _BTDISCONNECTREQUEST._serialized_end=869
  _BTDISCONNECTRESPONSE._serialized_start=871
  _BTDISCONNECTRESPONSE._serialized_end=920
  _BTPAIRREQUEST._serialized_start=922
  _BTPAIRREQUEST._serialized_end=954
  _BTPAIRRESPONSE._serialized_start=956
  _BTPAIRRESPONSE._serialized_end=999
  _BTUNPAIRREQUEST._serialized_start=1001
  _BTUNPAIRREQUEST._serialized_end=1035
  _BTUNPAIRRESPONSE._serialized_start=1037
  _BTUNPAIRRESPONSE._serialized_end=1082
  _BTSTATELISTENREQUEST._serialized_start=1084
  _BTSTATELISTENREQUEST._serialized_end=1106
  _BTSTATELISTENRESPONSE._serialized_start=1108
  _BTSTATELISTENRESPONSE._serialized_end=1158
  _BLUETOOTHSERVICEGRPC._serialized_start=1161
  _BLUETOOTHSERVICEGRPC._serialized_end=2250
# @@protoc_insertion_point(module_scope)
