# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rnetwork.proto\x12\x0eNetworkPackage\"\x16\n\x14NetworkCommonRequest\"A\n\x12WifiConnectRequest\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x0e\n\x06passwd\x18\x02 \x01(\t\x12\r\n\x05saved\x18\x03 \x01(\x08\"i\n\x13WifiConnectResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04ssid\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\x05\x12\r\n\x05\x62ssid\x18\x05 \x01(\t\x12\x0b\n\x03\x65xt\x18\x06 \x01(\t\"#\n\x11WifiEnableRequest\x12\x0e\n\x06\x65nable\x18\x01 \x01(\t\"[\n\x0cWifiListInfo\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x0c\n\x04rssi\x18\x02 \x01(\x05\x12\r\n\x05\x62ssid\x18\x03 \x01(\t\x12\x11\n\tfrequency\x18\x04 \x01(\x05\x12\r\n\x05\x66lags\x18\x05 \x01(\t\"T\n\rWifiSavedInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04ssid\x18\x02 \x01(\t\x12\r\n\x05\x62ssid\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0b\n\x03\x65xt\x18\x05 \x01(\t\"\x8b\x01\n\x10WifiListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x1c.NetworkPackage.WifiListInfo\x12\x30\n\tsaveDwifi\x18\x04 \x03(\x0b\x32\x1d.NetworkPackage.WifiSavedInfo\"\xe2\x01\n\rWifiStateInfo\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x0b\n\x03mac\x18\x02 \x01(\t\x12\x0c\n\x04\x66req\x18\x03 \x01(\t\x12\x0c\n\x04ssid\x18\x04 \x01(\t\x12\x0c\n\x04rssi\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x0c\n\x04mode\x18\x07 \x01(\t\x12\x10\n\x08key_mgmt\x18\x08 \x01(\t\x12\x14\n\x0cgroup_cipher\x18\t \x01(\t\x12\x17\n\x0fpairwise_cipher\x18\n \x01(\t\x12\x0c\n\x04uuid\x18\x0b \x01(\t\x12\x1a\n\x12p2p_device_address\x18\x0c \x01(\t\"[\n\x11WifiStateResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12+\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1d.NetworkPackage.WifiStateInfo\"6\n\x12HotspotInfoRequest\x12\x10\n\x08hot_name\x18\x01 \x01(\t\x12\x0e\n\x06passwd\x18\x02 \x01(\t\"@\n\x14HotspotStateResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\x05\"2\n\x15NetworkCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"C\n\x16\x42TJoypadStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\")\n\x17SetBrocastEnableRequest\x12\x0e\n\x06\x65nable\x18\x01 \x01(\t\"&\n\x15SetBrocastPortRequest\x12\r\n\x05nPort\x18\x01 \x01(\t\"&\n\x15SendBrocastMsgRequest\x12\r\n\x05stMsg\x18\x01 \x01(\t\"T\n\x1dGetReceivedBrocastMsgResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x18\n\x10received_message\x18\x03 \x01(\t2\xcd\x0b\n\x12NetworkServiceGrpc\x12W\n\x0bgetWifiList\x12$.NetworkPackage.NetworkCommonRequest\x1a .NetworkPackage.WifiListResponse\"\x00\x12Z\n\x0b\x63onnectWifi\x12\".NetworkPackage.WifiConnectRequest\x1a#.NetworkPackage.WifiConnectResponse\"\x00\x30\x01\x12Z\n\rgetWifiStatus\x12$.NetworkPackage.NetworkCommonRequest\x1a!.NetworkPackage.WifiStateResponse\"\x00\x12[\n\rsetWifiEnable\x12!.NetworkPackage.WifiEnableRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12_\n\x0e\x64isconnectWifi\x12$.NetworkPackage.NetworkCommonRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12\x65\n\x16startWifiStateListener\x12$.NetworkPackage.NetworkCommonRequest\x1a!.NetworkPackage.WifiStateResponse\"\x00\x30\x01\x12\x66\n\x15stopWifiStateListener\x12$.NetworkPackage.NetworkCommonRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12[\n\x0cstartHotspot\x12\".NetworkPackage.HotspotInfoRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12\\\n\x0bstopHotspot\x12$.NetworkPackage.NetworkCommonRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12_\n\x0fgetHotspotState\x12$.NetworkPackage.NetworkCommonRequest\x1a$.NetworkPackage.HotspotStateResponse\"\x00\x12\x63\n\x11getBTJoypadStatus\x12$.NetworkPackage.NetworkCommonRequest\x1a&.NetworkPackage.BTJoypadStatusResponse\"\x00\x12\x64\n\x10setBrocastEnable\x12\'.NetworkPackage.SetBrocastEnableRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12`\n\x0esetBrocastPort\x12%.NetworkPackage.SetBrocastPortRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12`\n\x0esendBrocastMsg\x12%.NetworkPackage.SendBrocastMsgRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12n\n\x15getReceivedBrocastMsg\x12$.NetworkPackage.NetworkCommonRequest\x1a-.NetworkPackage.GetReceivedBrocastMsgResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'network_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKCOMMONREQUEST._serialized_start=33
  _NETWORKCOMMONREQUEST._serialized_end=55
  _WIFICONNECTREQUEST._serialized_start=57
  _WIFICONNECTREQUEST._serialized_end=122
  _WIFICONNECTRESPONSE._serialized_start=124
  _WIFICONNECTRESPONSE._serialized_end=229
  _WIFIENABLEREQUEST._serialized_start=231
  _WIFIENABLEREQUEST._serialized_end=266
  _WIFILISTINFO._serialized_start=268
  _WIFILISTINFO._serialized_end=359
  _WIFISAVEDINFO._serialized_start=361
  _WIFISAVEDINFO._serialized_end=445
  _WIFILISTRESPONSE._serialized_start=448
  _WIFILISTRESPONSE._serialized_end=587
  _WIFISTATEINFO._serialized_start=590
  _WIFISTATEINFO._serialized_end=816
  _WIFISTATERESPONSE._serialized_start=818
  _WIFISTATERESPONSE._serialized_end=909
  _HOTSPOTINFOREQUEST._serialized_start=911
  _HOTSPOTINFOREQUEST._serialized_end=965
  _HOTSPOTSTATERESPONSE._serialized_start=967
  _HOTSPOTSTATERESPONSE._serialized_end=1031
  _NETWORKCOMMONRESPONSE._serialized_start=1033
  _NETWORKCOMMONRESPONSE._serialized_end=1083
  _BTJOYPADSTATUSRESPONSE._serialized_start=1085
  _BTJOYPADSTATUSRESPONSE._serialized_end=1152
  _SETBROCASTENABLEREQUEST._serialized_start=1154
  _SETBROCASTENABLEREQUEST._serialized_end=1195
  _SETBROCASTPORTREQUEST._serialized_start=1197
  _SETBROCASTPORTREQUEST._serialized_end=1235
  _SENDBROCASTMSGREQUEST._serialized_start=1237
  _SENDBROCASTMSGREQUEST._serialized_end=1275
  _GETRECEIVEDBROCASTMSGRESPONSE._serialized_start=1277
  _GETRECEIVEDBROCASTMSGRESPONSE._serialized_end=1361
  _NETWORKSERVICEGRPC._serialized_start=1364
  _NETWORKSERVICEGRPC._serialized_end=2849
# @@protoc_insertion_point(module_scope)
